import pandas as pd
from io import StringIO
import click
import os
import sys

JSON_DATA = """
[
  {"name": "上证指数", "symbol": "000001.XSHG"},
  {"name": "A股指数", "symbol": "000002.XSHG"},
  {"name": "B股指数", "symbol": "000003.XSHG"},
  {"name": "工业指数", "symbol": "000004.XSHG"},
  {"name": "商业指数", "symbol": "000005.XSHG"},
  {"name": "地产指数", "symbol": "000006.XSHG"},
  {"name": "公用指数", "symbol": "000007.XSHG"},
  {"name": "综合指数", "symbol": "000008.XSHG"},
  {"name": "上证380", "symbol": "000009.XSHG"},
  {"name": "上证180", "symbol": "000010.XSHG"},
  {"name": "基金指数", "symbol": "000011.XSHG"},
  {"name": "国债指数", "symbol": "000012.XSHG"},
  {"name": "上证企业债指数", "symbol": "000013.XSHG"},
  {"name": "红利指数", "symbol": "000015.XSHG"},
  {"name": "上证50", "symbol": "000016.XSHG"},
  {"name": "新综指", "symbol": "000017.XSHG"},
  {"name": "180金融", "symbol": "000018.XSHG"},
  {"name": "治理指数", "symbol": "000019.XSHG"},
  {"name": "中型综指", "symbol": "000020.XSHG"},
  {"name": "180治理", "symbol": "000021.XSHG"},
  {"name": "上证公司债指数", "symbol": "000022.XSHG"},
  {"name": "180基建", "symbol": "000025.XSHG"},
  {"name": "180资源", "symbol": "000026.XSHG"},
  {"name": "180运输", "symbol": "000027.XSHG"},
  {"name": "180成长", "symbol": "000028.XSHG"},
  {"name": "180价值", "symbol": "000029.XSHG"},
  {"name": "180R成长", "symbol": "000030.XSHG"},
  {"name": "180R价值", "symbol": "000031.XSHG"},
  {"name": "上证能源", "symbol": "000032.XSHG"},
  {"name": "上证材料", "symbol": "000033.XSHG"},
  {"name": "上证工业", "symbol": "000034.XSHG"},
  {"name": "上证可选", "symbol": "000035.XSHG"},
  {"name": "上证消费", "symbol": "000036.XSHG"},
  {"name": "上证医药", "symbol": "000037.XSHG"},
  {"name": "上证金融", "symbol": "000038.XSHG"},
  {"name": "上证信息", "symbol": "000039.XSHG"},
  {"name": "上证电信", "symbol": "000040.XSHG"},
  {"name": "上证公用", "symbol": "000041.XSHG"},
  {"name": "上证央企", "symbol": "000042.XSHG"},
  {"name": "超大盘", "symbol": "000043.XSHG"},
  {"name": "上证中盘", "symbol": "000044.XSHG"},
  {"name": "上证小盘", "symbol": "000045.XSHG"},
  {"name": "上证中小", "symbol": "000046.XSHG"},
  {"name": "上证全指", "symbol": "000047.XSHG"},
  {"name": "责任指数", "symbol": "000048.XSHG"},
  {"name": "上证民企", "symbol": "000049.XSHG"},
  {"name": "50等权", "symbol": "000050.XSHG"},
  {"name": "180等权", "symbol": "000051.XSHG"},
  {"name": "50基本", "symbol": "000052.XSHG"},
  {"name": "180基本", "symbol": "000053.XSHG"},
  {"name": "上证海外", "symbol": "000054.XSHG"},
  {"name": "上证地企", "symbol": "000055.XSHG"},
  {"name": "上证国企", "symbol": "000056.XSHG"},
  {"name": "全指成长", "symbol": "000057.XSHG"},
  {"name": "全指价值", "symbol": "000058.XSHG"},
  {"name": "全R成长", "symbol": "000059.XSHG"},
  {"name": "全R价值", "symbol": "000060.XSHG"},
  {"name": "沪企债30", "symbol": "000061.XSHG"},
  {"name": "上证沪企", "symbol": "000062.XSHG"},
  {"name": "上证周期", "symbol": "000063.XSHG"},
  {"name": "非周期", "symbol": "000064.XSHG"},
  {"name": "上证龙头", "symbol": "000065.XSHG"},
  {"name": "上证商品", "symbol": "000066.XSHG"},
  {"name": "上证新兴", "symbol": "000067.XSHG"},
  {"name": "上证资源", "symbol": "000068.XSHG"},
  {"name": "消费80", "symbol": "000069.XSHG"},
  {"name": "能源等权", "symbol": "000070.XSHG"},
  {"name": "材料等权", "symbol": "000071.XSHG"},
  {"name": "工业等权", "symbol": "000072.XSHG"},
  {"name": "可选等权", "symbol": "000073.XSHG"},
  {"name": "消费等权", "symbol": "000074.XSHG"},
  {"name": "医药等权", "symbol": "000075.XSHG"},
  {"name": "金融等权", "symbol": "000076.XSHG"},
  {"name": "信息等权", "symbol": "000077.XSHG"},
  {"name": "电信等权", "symbol": "000078.XSHG"},
  {"name": "公用等权", "symbol": "000079.XSHG"},
  {"name": "上证流通", "symbol": "000090.XSHG"},
  {"name": "沪财中小", "symbol": "000091.XSHG"},
  {"name": "资源50", "symbol": "000092.XSHG"},
  {"name": "180分层", "symbol": "000093.XSHG"},
  {"name": "上证上游", "symbol": "000094.XSHG"},
  {"name": "上证中游", "symbol": "000095.XSHG"},
  {"name": "上证下游", "symbol": "000096.XSHG"},
  {"name": "高端装备", "symbol": "000097.XSHG"},
  {"name": "上证F200", "symbol": "000098.XSHG"},
  {"name": "上证F300", "symbol": "000099.XSHG"},
  {"name": "上证F500", "symbol": "000100.XSHG"},
  {"name": "5年信用", "symbol": "000101.XSHG"},
  {"name": "沪投资品", "symbol": "000102.XSHG"},
  {"name": "沪消费品", "symbol": "000103.XSHG"},
  {"name": "380能源", "symbol": "000104.XSHG"},
  {"name": "380材料", "symbol": "000105.XSHG"},
  {"name": "380工业", "symbol": "000106.XSHG"},
  {"name": "380可选", "symbol": "000107.XSHG"},
  {"name": "380消费", "symbol": "000108.XSHG"},
  {"name": "380医药", "symbol": "000109.XSHG"},
  {"name": "380金融", "symbol": "000110.XSHG"},
  {"name": "380信息", "symbol": "000111.XSHG"},
  {"name": "380电信", "symbol": "000112.XSHG"},
  {"name": "380公用", "symbol": "000113.XSHG"},
  {"name": "持续产业", "symbol": "000114.XSHG"},
  {"name": "380等权", "symbol": "000115.XSHG"},
  {"name": "信用100", "symbol": "000116.XSHG"},
  {"name": "380成长", "symbol": "000117.XSHG"},
  {"name": "380价值", "symbol": "000118.XSHG"},
  {"name": "380R成长", "symbol": "000119.XSHG"},
  {"name": "380R价值", "symbol": "000120.XSHG"},
  {"name": "医药主题", "symbol": "000121.XSHG"},
  {"name": "农业主题", "symbol": "000122.XSHG"},
  {"name": "180动态", "symbol": "000123.XSHG"},
  {"name": "180稳定", "symbol": "000125.XSHG"},
  {"name": "消费50", "symbol": "000126.XSHG"},
  {"name": "380基本", "symbol": "000128.XSHG"},
  {"name": "180波动", "symbol": "000129.XSHG"},
  {"name": "380波动", "symbol": "000130.XSHG"},
  {"name": "上证高新", "symbol": "000131.XSHG"},
  {"name": "上证100", "symbol": "000132.XSHG"},
  {"name": "上证150", "symbol": "000133.XSHG"},
  {"name": "上证银行", "symbol": "000134.XSHG"},
  {"name": "180高贝", "symbol": "000135.XSHG"},
  {"name": "180低贝", "symbol": "000136.XSHG"},
  {"name": "380高贝", "symbol": "000137.XSHG"},
  {"name": "380低贝", "symbol": "000138.XSHG"},
  {"name": "上证转债", "symbol": "000139.XSHG"},
  {"name": "380动态", "symbol": "000141.XSHG"},
  {"name": "380稳定", "symbol": "000142.XSHG"},
  {"name": "优势资源", "symbol": "000145.XSHG"},
  {"name": "优势制造", "symbol": "000146.XSHG"},
  {"name": "优势消费", "symbol": "000147.XSHG"},
  {"name": "消费领先", "symbol": "000148.XSHG"},
  {"name": "180红利", "symbol": "000149.XSHG"},
  {"name": "380红利", "symbol": "000150.XSHG"},
  {"name": "上国红利", "symbol": "000151.XSHG"},
  {"name": "上央红利", "symbol": "000152.XSHG"},
  {"name": "上民红利", "symbol": "000153.XSHG"},
  {"name": "市值百强", "symbol": "000155.XSHG"},
  {"name": "上证环保", "symbol": "000158.XSHG"},
  {"name": "上证沪股通指数", "symbol": "000159.XSHG"},
  {"name": "上证一带一路主题指数", "symbol": "000160.XSHG"},
  {"name": "上证中国制造2025主题指数", "symbol": "000161.XSHG"},
  {"name": "上证互联网+主题指数", "symbol": "000162.XSHG"},
  {"name": "沪深300", "symbol": "000300.XSHG"},
  {"name": "资源80", "symbol": "000801.XSHG"},
  {"name": "500沪市", "symbol": "000802.XSHG"},
  {"name": "300波动", "symbol": "000803.XSHG"},
  {"name": "500波动", "symbol": "000804.XSHG"},
  {"name": "A股资源", "symbol": "000805.XSHG"},
  {"name": "消费服务", "symbol": "000806.XSHG"},
  {"name": "食品饮料", "symbol": "000807.XSHG"},
  {"name": "医药生物", "symbol": "000808.XSHG"},
  {"name": "细分农业", "symbol": "000809.XSHG"},
  {"name": "细分能源", "symbol": "000810.XSHG"},
  {"name": "细分有色", "symbol": "000811.XSHG"},
  {"name": "细分机械", "symbol": "000812.XSHG"},
  {"name": "细分化工", "symbol": "000813.XSHG"},
  {"name": "细分医药", "symbol": "000814.XSHG"},
  {"name": "细分食品", "symbol": "000815.XSHG"},
  {"name": "细分地产", "symbol": "000816.XSHG"},
  {"name": "兴证海峡", "symbol": "000817.XSHG"},
  {"name": "细分金融", "symbol": "000818.XSHG"},
  {"name": "有色金属", "symbol": "000819.XSHG"},
  {"name": "煤炭指数", "symbol": "000820.XSHG"},
  {"name": "300红利", "symbol": "000821.XSHG"},
  {"name": "500红利", "symbol": "000822.XSHG"},
  {"name": "中证800有色金属指数", "symbol": "000823.XSHG"},
  {"name": "国企红利", "symbol": "000824.XSHG"},
  {"name": "央企红利", "symbol": "000825.XSHG"},
  {"name": "民企红利", "symbol": "000826.XSHG"},
  {"name": "中证环保", "symbol": "000827.XSHG"},
  {"name": "300高贝", "symbol": "000828.XSHG"},
  {"name": "300低贝", "symbol": "000829.XSHG"},
  {"name": "500高贝", "symbol": "000830.XSHG"},
  {"name": "500低贝", "symbol": "000831.XSHG"},
  {"name": "中证转债", "symbol": "000832.XSHG"},
  {"name": "中高企债", "symbol": "000833.XSHG"},
  {"name": "创业价值", "symbol": "000838.XSHG"},
  {"name": "浙企综指", "symbol": "000839.XSHG"},
  {"name": "浙江民企", "symbol": "000840.XSHG"},
  {"name": "800医药", "symbol": "000841.XSHG"},
  {"name": "800等权", "symbol": "000842.XSHG"},
  {"name": "300动态", "symbol": "000843.XSHG"},
  {"name": "300稳定", "symbol": "000844.XSHG"},
  {"name": "ESG100", "symbol": "000846.XSHG"},
  {"name": "中证腾安价值100指数", "symbol": "000847.XSHG"},
  {"name": "沪深300非银行金融指数", "symbol": "000849.XSHG"},
  {"name": "沪深300有色金属指数", "symbol": "000850.XSHG"},
  {"name": "中证百度百发策略100指数", "symbol": "000851.XSHG"},
  {"name": "中证1000指数", "symbol": "000852.XSHG"},
  {"name": "中证申万一带一路主题投资指数", "symbol": "000853.XSHG"},
  {"name": "央视财经500指数", "symbol": "000855.XSHG"},
  {"name": "小康指数", "symbol": "000901.XSHG"},
  {"name": "中证流通", "symbol": "000902.XSHG"},
  {"name": "中证100", "symbol": "000903.XSHG"},
  {"name": "中证200", "symbol": "000904.XSHG"},
  {"name": "中证500", "symbol": "000905.XSHG"},
  {"name": "中证800", "symbol": "000906.XSHG"},
  {"name": "中证700", "symbol": "000907.XSHG"},
  {"name": "300能源", "symbol": "000908.XSHG"},
  {"name": "300材料", "symbol": "000909.XSHG"},
  {"name": "300工业", "symbol": "000910.XSHG"},
  {"name": "300可选", "symbol": "000911.XSHG"},
  {"name": "300消费", "symbol": "000912.XSHG"},
  {"name": "300医药", "symbol": "000913.XSHG"},
  {"name": "300金融", "symbol": "000914.XSHG"},
  {"name": "300信息", "symbol": "000915.XSHG"},
  {"name": "300电信", "symbol": "000916.XSHG"},
  {"name": "300公用", "symbol": "000917.XSHG"},
  {"name": "300成长", "symbol": "000918.XSHG"},
  {"name": "300价值", "symbol": "000919.XSHG"},
  {"name": "300R成长", "symbol": "000920.XSHG"},
  {"name": "300R价值", "symbol": "000921.XSHG"},
  {"name": "中证红利", "symbol": "000922.XSHG"},
  {"name": "公司债", "symbol": "000923.XSHG"},
  {"name": "基本面50", "symbol": "000925.XSHG"},
  {"name": "中证央企", "symbol": "000926.XSHG"},
  {"name": "央企100", "symbol": "000927.XSHG"},
  {"name": "中证能源", "symbol": "000928.XSHG"},
  {"name": "中证材料", "symbol": "000929.XSHG"},
  {"name": "中证工业", "symbol": "000930.XSHG"},
  {"name": "中证可选", "symbol": "000931.XSHG"},
  {"name": "中证消费", "symbol": "000932.XSHG"},
  {"name": "中证医药", "symbol": "000933.XSHG"},
  {"name": "中证金融", "symbol": "000934.XSHG"},
  {"name": "中证信息", "symbol": "000935.XSHG"},
  {"name": "中证电信", "symbol": "000936.XSHG"},
  {"name": "中证公用", "symbol": "000937.XSHG"},
  {"name": "中证民企", "symbol": "000938.XSHG"},
  {"name": "民企200", "symbol": "000939.XSHG"},
  {"name": "财富大盘", "symbol": "000940.XSHG"},
  {"name": "新能源", "symbol": "000941.XSHG"},
  {"name": "内地消费", "symbol": "000942.XSHG"},
  {"name": "内地基建", "symbol": "000943.XSHG"},
  {"name": "内地资源", "symbol": "000944.XSHG"},
  {"name": "内地运输", "symbol": "000945.XSHG"},
  {"name": "内地金融", "symbol": "000946.XSHG"},
  {"name": "内地银行", "symbol": "000947.XSHG"},
  {"name": "内地地产", "symbol": "000948.XSHG"},
  {"name": "内地农业", "symbol": "000949.XSHG"},
  {"name": "300基建", "symbol": "000950.XSHG"},
  {"name": "300银行", "symbol": "000951.XSHG"},
  {"name": "300地产", "symbol": "000952.XSHG"},
  {"name": "中证地企", "symbol": "000953.XSHG"},
  {"name": "地企100", "symbol": "000954.XSHG"},
  {"name": "中证国企", "symbol": "000955.XSHG"},
  {"name": "国企200", "symbol": "000956.XSHG"},
  {"name": "300运输", "symbol": "000957.XSHG"},
  {"name": "创业成长", "symbol": "000958.XSHG"},
  {"name": "银河99", "symbol": "000959.XSHG"},
  {"name": "中证龙头", "symbol": "000960.XSHG"},
  {"name": "中证上游", "symbol": "000961.XSHG"},
  {"name": "中证中游", "symbol": "000962.XSHG"},
  {"name": "中证下游", "symbol": "000963.XSHG"},
  {"name": "中证新兴", "symbol": "000964.XSHG"},
  {"name": "基本200", "symbol": "000965.XSHG"},
  {"name": "基本400", "symbol": "000966.XSHG"},
  {"name": "基本600", "symbol": "000967.XSHG"},
  {"name": "300周期", "symbol": "000968.XSHG"},
  {"name": "300非周", "symbol": "000969.XSHG"},
  {"name": "ESG40", "symbol": "000970.XSHG"},
  {"name": "等权90", "symbol": "000971.XSHG"},
  {"name": "300沪市", "symbol": "000972.XSHG"},
  {"name": "技术领先", "symbol": "000973.XSHG"},
  {"name": "中证800金融指数", "symbol": "000974.XSHG"},
  {"name": "钱江30", "symbol": "000975.XSHG"},
  {"name": "新华金牛", "symbol": "000976.XSHG"},
  {"name": "内地低碳", "symbol": "000977.XSHG"},
  {"name": "医药100", "symbol": "000978.XSHG"},
  {"name": "大宗商品", "symbol": "000979.XSHG"},
  {"name": "中证超大", "symbol": "000980.XSHG"},
  {"name": "300分层", "symbol": "000981.XSHG"},
  {"name": "500等权", "symbol": "000982.XSHG"},
  {"name": "智能资产", "symbol": "000983.XSHG"},
  {"name": "300等权", "symbol": "000984.XSHG"},
  {"name": "中证全指", "symbol": "000985.XSHG"},
  {"name": "全指能源", "symbol": "000986.XSHG"},
  {"name": "全指材料", "symbol": "000987.XSHG"},
  {"name": "全指工业", "symbol": "000988.XSHG"},
  {"name": "全指可选", "symbol": "000989.XSHG"},
  {"name": "全指消费", "symbol": "000990.XSHG"},
  {"name": "全指医药", "symbol": "000991.XSHG"},
  {"name": "全指金融", "symbol": "000992.XSHG"},
  {"name": "全指信息", "symbol": "000993.XSHG"},
  {"name": "全指电信", "symbol": "000994.XSHG"},
  {"name": "全指公用", "symbol": "000995.XSHG"},
  {"name": "领先行业", "symbol": "000996.XSHG"},
  {"name": "大消费", "symbol": "000997.XSHG"},
  {"name": "中证TMT", "symbol": "000998.XSHG"},
  {"name": "证两岸三地500指数", "symbol": "000999.XSHG"},
  {"name": "深证成指", "symbol": "399001.XSHE"},
  {"name": "深成指R", "symbol": "399002.XSHE"},
  {"name": "成份B指", "symbol": "399003.XSHE"},
  {"name": "深证100R", "symbol": "399004.XSHE"},
  {"name": "中小板指", "symbol": "399005.XSHE"},
  {"name": "创业板指", "symbol": "399006.XSHE"},
  {"name": "深证300", "symbol": "399007.XSHE"},
  {"name": "中小300", "symbol": "399008.XSHE"},
  {"name": "深证200", "symbol": "399009.XSHE"},
  {"name": "深证700", "symbol": "399010.XSHE"},
  {"name": "深证1000", "symbol": "399011.XSHE"},
  {"name": "创业300", "symbol": "399012.XSHE"},
  {"name": "深市精选", "symbol": "399013.XSHE"},
  {"name": "深证中小创新指数", "symbol": "399015.XSHE"},
  {"name": "新指数", "symbol": "399100.XSHE"},
  {"name": "中小板综", "symbol": "399101.XSHE"},
  {"name": "创业板综合指数", "symbol": "399102.XSHE"},
  {"name": "乐富指数", "symbol": "399103.XSHE"},
  {"name": "深证综指", "symbol": "399106.XSHE"},
  {"name": "深证A指", "symbol": "399107.XSHE"},
  {"name": "深证B指", "symbol": "399108.XSHE"},
  {"name": "农林指数", "symbol": "399231.XSHE"},
  {"name": "采矿指数", "symbol": "399232.XSHE"},
  {"name": "制造指数", "symbol": "399233.XSHE"},
  {"name": "水电指数", "symbol": "399234.XSHE"},
  {"name": "建筑指数", "symbol": "399235.XSHE"},
  {"name": "批零指数", "symbol": "399236.XSHE"},
  {"name": "运输指数", "symbol": "399237.XSHE"},
  {"name": "餐饮指数", "symbol": "399238.XSHE"},
  {"name": "IT指数", "symbol": "399239.XSHE"},
  {"name": "金融指数", "symbol": "399240.XSHE"},
  {"name": "地产指数", "symbol": "399241.XSHE"},
  {"name": "商务指数", "symbol": "399242.XSHE"},
  {"name": "科研指数", "symbol": "399243.XSHE"},
  {"name": "公共指数", "symbol": "399244.XSHE"},
  {"name": "文化指数", "symbol": "399248.XSHE"},
  {"name": "综企指数", "symbol": "399249.XSHE"},
  {"name": "深证中高等级信用债指数", "symbol": "399298.XSHE"},
  {"name": "深证中低等级信用债指数", "symbol": "399299.XSHE"},
  {"name": "沪深300", "symbol": "399300.XSHE"},
  {"name": "深信用债", "symbol": "399301.XSHE"},
  {"name": "深公司债", "symbol": "399302.XSHE"},
  {"name": "国证2000", "symbol": "399303.XSHE"},
  {"name": "基金指数", "symbol": "399305.XSHE"},
  {"name": "深证ETF", "symbol": "399306.XSHE"},
  {"name": "深证转债", "symbol": "399307.XSHE"},
  {"name": "国证50", "symbol": "399310.XSHE"},
  {"name": "国证1000", "symbol": "399311.XSHE"},
  {"name": "国证300", "symbol": "399312.XSHE"},
  {"name": "巨潮100", "symbol": "399313.XSHE"},
  {"name": "巨潮大盘", "symbol": "399314.XSHE"},
  {"name": "巨潮中盘", "symbol": "399315.XSHE"},
  {"name": "巨潮小盘", "symbol": "399316.XSHE"},
  {"name": "国证A指", "symbol": "399317.XSHE"},
  {"name": "巨潮B股指数", "symbol": "399318.XSHE"},
  {"name": "资源优势", "symbol": "399319.XSHE"},
  {"name": "国证服务", "symbol": "399320.XSHE"},
  {"name": "国证红利", "symbol": "399321.XSHE"},
  {"name": "国证治理", "symbol": "399322.XSHE"},
  {"name": "深证红利", "symbol": "399324.XSHE"},
  {"name": "成长40", "symbol": "399326.XSHE"},
  {"name": "深证治理", "symbol": "399328.XSHE"},
  {"name": "深证100", "symbol": "399330.XSHE"},
  {"name": "深证创新", "symbol": "399332.XSHE"},
  {"name": "中小板R", "symbol": "399333.XSHE"},
  {"name": "深证央企", "symbol": "399335.XSHE"},
  {"name": "深证民营", "symbol": "399337.XSHE"},
  {"name": "深证科技", "symbol": "399339.XSHE"},
  {"name": "深证责任", "symbol": "399341.XSHE"},
  {"name": "深证300R", "symbol": "399344.XSHE"},
  {"name": "深证成长", "symbol": "399346.XSHE"},
  {"name": "深证价值", "symbol": "399348.XSHE"},
  {"name": "皖江30", "symbol": "399350.XSHE"},
  {"name": "深报指数", "symbol": "399351.XSHE"},
  {"name": "深报综指", "symbol": "399352.XSHE"},
  {"name": "国证物流", "symbol": "399353.XSHE"},
  {"name": "长三角", "symbol": "399355.XSHE"},
  {"name": "珠三角", "symbol": "399356.XSHE"},
  {"name": "环渤海", "symbol": "399357.XSHE"},
  {"name": "泰达指数", "symbol": "399358.XSHE"},
  {"name": "国证基建", "symbol": "399359.XSHE"},
  {"name": "国证装备", "symbol": "399360.XSHE"},
  {"name": "国证商业", "symbol": "399361.XSHE"},
  {"name": "国证民营", "symbol": "399362.XSHE"},
  {"name": "计算机指", "symbol": "399363.XSHE"},
  {"name": "中金消费", "symbol": "399364.XSHE"},
  {"name": "国证农业", "symbol": "399365.XSHE"},
  {"name": "国证大宗", "symbol": "399366.XSHE"},
  {"name": "巨潮地产", "symbol": "399367.XSHE"},
  {"name": "国证军工", "symbol": "399368.XSHE"},
  {"name": "CBN-兴全", "symbol": "399369.XSHE"},
  {"name": "国证成长", "symbol": "399370.XSHE"},
  {"name": "国证价值", "symbol": "399371.XSHE"},
  {"name": "大盘成长", "symbol": "399372.XSHE"},
  {"name": "大盘价值", "symbol": "399373.XSHE"},
  {"name": "中盘成长", "symbol": "399374.XSHE"},
  {"name": "中盘价值", "symbol": "399375.XSHE"},
  {"name": "小盘成长", "symbol": "399376.XSHE"},
  {"name": "小盘价值", "symbol": "399377.XSHE"},
  {"name": "南方低碳", "symbol": "399378.XSHE"},
  {"name": "国证基金", "symbol": "399379.XSHE"},
  {"name": "国证ETF", "symbol": "399380.XSHE"},
  {"name": "1000能源", "symbol": "399381.XSHE"},
  {"name": "1000材料", "symbol": "399382.XSHE"},
  {"name": "1000工业", "symbol": "399383.XSHE"},
  {"name": "1000可选", "symbol": "399384.XSHE"},
  {"name": "1000消费", "symbol": "399385.XSHE"},
  {"name": "1000医药", "symbol": "399386.XSHE"},
  {"name": "1000金融", "symbol": "399387.XSHE"},
  {"name": "1000信息", "symbol": "399388.XSHE"},
  {"name": "国证通信", "symbol": "399389.XSHE"},
  {"name": "1000公用", "symbol": "399390.XSHE"},
  {"name": "投资时钟", "symbol": "399391.XSHE"},
  {"name": "国证新兴", "symbol": "399392.XSHE"},
  {"name": "国证地产", "symbol": "399393.XSHE"},
  {"name": "国证医药", "symbol": "399394.XSHE"},
  {"name": "国证有色", "symbol": "399395.XSHE"},
  {"name": "国证食品", "symbol": "399396.XSHE"},
  {"name": "OCT文化", "symbol": "399397.XSHE"},
  {"name": "绩效指数", "symbol": "399398.XSHE"},
  {"name": "中经GDP", "symbol": "399399.XSHE"},
  {"name": "大中盘", "symbol": "399400.XSHE"},
  {"name": "中小盘", "symbol": "399401.XSHE"},
  {"name": "周期100", "symbol": "399402.XSHE"},
  {"name": "防御100", "symbol": "399403.XSHE"},
  {"name": "大盘低波", "symbol": "399404.XSHE"},
  {"name": "大盘高贝", "symbol": "399405.XSHE"},
  {"name": "中盘低波", "symbol": "399406.XSHE"},
  {"name": "中盘高贝", "symbol": "399407.XSHE"},
  {"name": "小盘低波", "symbol": "399408.XSHE"},
  {"name": "小盘高贝", "symbol": "399409.XSHE"},
  {"name": "苏州率先", "symbol": "399410.XSHE"},
  {"name": "红利100", "symbol": "399411.XSHE"},
  {"name": "国证新能", "symbol": "399412.XSHE"},
  {"name": "国证转债", "symbol": "399413.XSHE"},
  {"name": "I100", "symbol": "399415.XSHE"},
  {"name": "I300", "symbol": "399416.XSHE"},
  {"name": "国证新能源汽车指数", "symbol": "399417.XSHE"},
  {"name": "国证国家安全指数", "symbol": "399418.XSHE"},
  {"name": "国证高铁指数", "symbol": "399419.XSHE"},
  {"name": "国证保险证券指数", "symbol": "399420.XSHE"},
  {"name": "中关村50指数", "symbol": "399423.XSHE"},
  {"name": "国证德高行专利领先指数", "symbol": "399427.XSHE"},
  {"name": "国证定向增发指数", "symbol": "399428.XSHE"},
  {"name": "新丝路指数", "symbol": "399429.XSHE"},
  {"name": "国证银行行业指数", "symbol": "399431.XSHE"},
  {"name": "国证汽车与汽车零配件行业指数", "symbol": "399432.XSHE"},
  {"name": "国证交通运输行业指数", "symbol": "399433.XSHE"},
  {"name": "国证传媒行业指数", "symbol": "399434.XSHE"},
  {"name": "国证农牧渔产品行业指数", "symbol": "399435.XSHE"},
  {"name": "国证煤炭行业指数", "symbol": "399436.XSHE"},
  {"name": "国证证券行业指数", "symbol": "399437.XSHE"},
  {"name": "国证电力公用事业行业指数", "symbol": "399438.XSHE"},
  {"name": "国证石油天然气行业指数", "symbol": "399439.XSHE"},
  {"name": "国证黑色金属行业指数", "symbol": "399440.XSHE"},
  {"name": "国证生物医药指数", "symbol": "399441.XSHE"},
  {"name": "企债指数", "symbol": "399481.XSHE"},
  {"name": "央视50", "symbol": "399550.XSHE"},
  {"name": "央视创新", "symbol": "399551.XSHE"},
  {"name": "央视成长", "symbol": "399552.XSHE"},
  {"name": "央视回报", "symbol": "399553.XSHE"},
  {"name": "央视治理", "symbol": "399554.XSHE"},
  {"name": "央视责任", "symbol": "399555.XSHE"},
  {"name": "央视生态", "symbol": "399556.XSHE"},
  {"name": "央视文化", "symbol": "399557.XSHE"},
  {"name": "中小成长", "symbol": "399602.XSHE"},
  {"name": "中小价值", "symbol": "399604.XSHE"},
  {"name": "创业板R", "symbol": "399606.XSHE"},
  {"name": "科技100", "symbol": "399608.XSHE"},
  {"name": "TMT50", "symbol": "399610.XSHE"},
  {"name": "中创100R", "symbol": "399611.XSHE"},
  {"name": "中创100", "symbol": "399612.XSHE"},
  {"name": "深证能源", "symbol": "399613.XSHE"},
  {"name": "深证材料", "symbol": "399614.XSHE"},
  {"name": "深证工业", "symbol": "399615.XSHE"},
  {"name": "深证可选", "symbol": "399616.XSHE"},
  {"name": "深证消费", "symbol": "399617.XSHE"},
  {"name": "深证医药", "symbol": "399618.XSHE"},
  {"name": "深证金融", "symbol": "399619.XSHE"},
  {"name": "深证信息", "symbol": "399620.XSHE"},
  {"name": "深证电信", "symbol": "399621.XSHE"},
  {"name": "深证公用", "symbol": "399622.XSHE"},
  {"name": "中小基础", "symbol": "399623.XSHE"},
  {"name": "中创400", "symbol": "399624.XSHE"},
  {"name": "中创500", "symbol": "399625.XSHE"},
  {"name": "中创成长", "symbol": "399626.XSHE"},
  {"name": "中创价值", "symbol": "399627.XSHE"},
  {"name": "700成长", "symbol": "399628.XSHE"},
  {"name": "700价值", "symbol": "399629.XSHE"},
  {"name": "1000成长", "symbol": "399630.XSHE"},
  {"name": "1000价值", "symbol": "399631.XSHE"},
  {"name": "深100EW", "symbol": "399632.XSHE"},
  {"name": "深300EW", "symbol": "399633.XSHE"},
  {"name": "中小板EW", "symbol": "399634.XSHE"},
  {"name": "创业板EW", "symbol": "399635.XSHE"},
  {"name": "深证装备", "symbol": "399636.XSHE"},
  {"name": "深证地产", "symbol": "399637.XSHE"},
  {"name": "深证环保", "symbol": "399638.XSHE"},
  {"name": "深证大宗", "symbol": "399639.XSHE"},
  {"name": "创业基础", "symbol": "399640.XSHE"},
  {"name": "深证新兴", "symbol": "399641.XSHE"},
  {"name": "中小新兴", "symbol": "399642.XSHE"},
  {"name": "创业新兴", "symbol": "399643.XSHE"},
  {"name": "深证时钟", "symbol": "399644.XSHE"},
  {"name": "100低波", "symbol": "399645.XSHE"},
  {"name": "深消费50", "symbol": "399646.XSHE"},
  {"name": "深医药50", "symbol": "399647.XSHE"},
  {"name": "深证GDP", "symbol": "399648.XSHE"},
  {"name": "中小红利", "symbol": "399649.XSHE"},
  {"name": "中小治理", "symbol": "399650.XSHE"},
  {"name": "中小责任", "symbol": "399651.XSHE"},
  {"name": "中创高新", "symbol": "399652.XSHE"},
  {"name": "深证龙头", "symbol": "399653.XSHE"},
  {"name": "深证文化", "symbol": "399654.XSHE"},
  {"name": "深证绩效", "symbol": "399655.XSHE"},
  {"name": "100绩效", "symbol": "399656.XSHE"},
  {"name": "300绩效", "symbol": "399657.XSHE"},
  {"name": "中小绩效", "symbol": "399658.XSHE"},
  {"name": "深成指EW", "symbol": "399659.XSHE"},
  {"name": "中创EW", "symbol": "399660.XSHE"},
  {"name": "深证低波", "symbol": "399661.XSHE"},
  {"name": "深证高贝", "symbol": "399662.XSHE"},
  {"name": "中小低波", "symbol": "399663.XSHE"},
  {"name": "中小高贝", "symbol": "399664.XSHE"},
  {"name": "中创低波", "symbol": "399665.XSHE"},
  {"name": "中创高贝", "symbol": "399666.XSHE"},
  {"name": "创业板G", "symbol": "399667.XSHE"},
  {"name": "创业板V", "symbol": "399668.XSHE"},
  {"name": "深证农业", "symbol": "399669.XSHE"},
  {"name": "深周期50", "symbol": "399670.XSHE"},
  {"name": "深防御50", "symbol": "399671.XSHE"},
  {"name": "深红利50", "symbol": "399672.XSHE"},
  {"name": "创业板50", "symbol": "399673.XSHE"},
  {"name": "深A医药卫生指数", "symbol": "399674.XSHE"},
  {"name": "深A软件与互联网指数", "symbol": "399675.XSHE"},
  {"name": "深A医药卫生等权指数", "symbol": "399676.XSHE"},
  {"name": "深A软件与互联网等权指数", "symbol": "399677.XSHE"},
  {"name": "深证次新股指数", "symbol": "399678.XSHE"},
  {"name": "深证200指数", "symbol": "399679.XSHE"},
  {"name": "深成能源行业指数", "symbol": "399680.XSHE"},
  {"name": "深成原材料行业指数", "symbol": "399681.XSHE"},
  {"name": "深成工业行业指数", "symbol": "399682.XSHE"},
  {"name": "深成可选消费行业指数", "symbol": "399683.XSHE"},
  {"name": "深成主要消费行业指数", "symbol": "399684.XSHE"},
  {"name": "深成医药卫生行业指数", "symbol": "399685.XSHE"},
  {"name": "深成金融地产行业指数", "symbol": "399686.XSHE"},
  {"name": "深成信息技术行业指数", "symbol": "399687.XSHE"},
  {"name": "深成电信业务行业指数", "symbol": "399688.XSHE"},
  {"name": "深成公用事业行业指数", "symbol": "399689.XSHE"},
  {"name": "深证F60", "symbol": "399701.XSHE"},
  {"name": "深证F120", "symbol": "399702.XSHE"},
  {"name": "深证F200", "symbol": "399703.XSHE"},
  {"name": "深证上游", "symbol": "399704.XSHE"},
  {"name": "深证中游", "symbol": "399705.XSHE"},
  {"name": "深证下游", "symbol": "399706.XSHE"},
  {"name": "中证申万证券行业指数", "symbol": "399707.XSHE"},
  {"name": "500深市", "symbol": "399802.XSHE"},
  {"name": "中证工业4.0指数", "symbol": "399803.XSHE"},
  {"name": "中证体育产业指数", "symbol": "399804.XSHE"},
  {"name": "中证互联网金融指数", "symbol": "399805.XSHE"},
  {"name": "中证环境治理指数", "symbol": "399806.XSHE"},
  {"name": "中证高铁产业指数", "symbol": "399807.XSHE"},
  {"name": "中证新能源指数", "symbol": "399808.XSHE"},
  {"name": "中证方正富邦保险主题指数", "symbol": "399809.XSHE"},
  {"name": "中证申万传媒行业投资指数", "symbol": "399810.XSHE"},
  {"name": "中证申万电子行业投资指数", "symbol": "399811.XSHE"},
  {"name": "中证养老产业指数", "symbol": "399812.XSHE"},
  {"name": "中证国防安全指数", "symbol": "399813.XSHE"},
  {"name": "中证大农业指数", "symbol": "399814.XSHE"},
  {"name": "中证阿拉善生态主题100指数", "symbol": "399817.XSHE"},
  {"name": "中证南方小康产业指数", "symbol": "399901.XSHE"},
  {"name": "中证100指数", "symbol": "399903.XSHE"},
  {"name": "中证中盘200指数", "symbol": "399904.XSHE"},
  {"name": "中证500", "symbol": "399905.XSHE"},
  {"name": "中证中小盘700指数", "symbol": "399907.XSHE"},
  {"name": "沪深300能源指数", "symbol": "399908.XSHE"},
  {"name": "沪深300原材料指数", "symbol": "399909.XSHE"},
  {"name": "沪深300工业指数", "symbol": "399910.XSHE"},
  {"name": "沪深300可选消费指数", "symbol": "399911.XSHE"},
  {"name": "沪深300主要消费指数", "symbol": "399912.XSHE"},
  {"name": "沪深300医药卫生指数", "symbol": "399913.XSHE"},
  {"name": "沪深300金融地产指数", "symbol": "399914.XSHE"},
  {"name": "沪深300信息技术指数", "symbol": "399915.XSHE"},
  {"name": "沪深300电信业务指数", "symbol": "399916.XSHE"},
  {"name": "沪深300公用事业指数", "symbol": "399917.XSHE"},
  {"name": "沪深300成长指数", "symbol": "399918.XSHE"},
  {"name": "沪深300价值指数", "symbol": "399919.XSHE"},
  {"name": "沪深300相对成长指数", "symbol": "399920.XSHE"},
  {"name": "中证红利指数", "symbol": "399922.XSHE"},
  {"name": "中证锐联基本面50指数", "symbol": "399925.XSHE"},
  {"name": "中证中央企业综合指数", "symbol": "399926.XSHE"},
  {"name": "中证中央企业100指数", "symbol": "399927.XSHE"},
  {"name": "中证能源指数", "symbol": "399928.XSHE"},
  {"name": "中证原材料指数", "symbol": "399929.XSHE"},
  {"name": "中证工业指数", "symbol": "399930.XSHE"},
  {"name": "中证可选消费指数", "symbol": "399931.XSHE"},
  {"name": "中证主要消费指数", "symbol": "399932.XSHE"},
  {"name": "中证医药卫生指数", "symbol": "399933.XSHE"},
  {"name": "中证金融地产指数", "symbol": "399934.XSHE"},
  {"name": "中证信息技术指数", "symbol": "399935.XSHE"},
  {"name": "中证电信业务指数", "symbol": "399936.XSHE"},
  {"name": "中证公用事业指数", "symbol": "399937.XSHE"},
  {"name": "中证民营企业综合指数", "symbol": "399938.XSHE"},
  {"name": "中证民营企业200指数", "symbol": "399939.XSHE"},
  {"name": "中证内地新能源主题指数", "symbol": "399941.XSHE"},
  {"name": "中证内地消费主题指数", "symbol": "399942.XSHE"},
  {"name": "中证内地基建主题指数", "symbol": "399943.XSHE"},
  {"name": "中证内地资源主题指数", "symbol": "399944.XSHE"},
  {"name": "中证内地运输主题指数", "symbol": "399945.XSHE"},
  {"name": "中证内地金融主题指数", "symbol": "399946.XSHE"},
  {"name": "中证内地银行主题指数", "symbol": "399947.XSHE"},
  {"name": "中证内地地产主题指数", "symbol": "399948.XSHE"},
  {"name": "中证内地农业主题指数", "symbol": "399949.XSHE"},
  {"name": "沪深300基建主题指数", "symbol": "399950.XSHE"},
  {"name": "沪深300银行指数", "symbol": "399951.XSHE"},
  {"name": "沪深300地产指数", "symbol": "399952.XSHE"},
  {"name": "中证地方国有企业综合指数", "symbol": "399953.XSHE"},
  {"name": "中证地方国有企业100指数", "symbol": "399954.XSHE"},
  {"name": "中证国有企业200指数", "symbol": "399956.XSHE"},
  {"name": "沪深300运输指数", "symbol": "399957.XSHE"},
  {"name": "中证创业成长指数", "symbol": "399958.XSHE"},
  {"name": "军工指数", "symbol": "399959.XSHE"},
  {"name": "中证龙头企业指数", "symbol": "399960.XSHE"},
  {"name": "中证上游资源产业指数", "symbol": "399961.XSHE"},
  {"name": "中证中游制造产业指数", "symbol": "399962.XSHE"},
  {"name": "中证下游消费与服务产业指数", "symbol": "399963.XSHE"},
  {"name": "中证新兴产业指数", "symbol": "399964.XSHE"},
  {"name": "800地产", "symbol": "399965.XSHE"},
  {"name": "800非银", "symbol": "399966.XSHE"},
  {"name": "中证军工", "symbol": "399967.XSHE"},
  {"name": "沪深300周期行业指数", "symbol": "399968.XSHE"},
  {"name": "沪深300非周期行业指数", "symbol": "399969.XSHE"},
  {"name": "中证移动互联网指数", "symbol": "399970.XSHE"},
  {"name": "中证传媒指数", "symbol": "399971.XSHE"},
  {"name": "300深市", "symbol": "399972.XSHE"},
  {"name": "中证国防指数", "symbol": "399973.XSHE"},
  {"name": "中证国有企业改革指数", "symbol": "399974.XSHE"},
  {"name": "中证全指证券公司指数(四级行业)", "symbol": "399975.XSHE"},
  {"name": "中证新能源汽车指数", "symbol": "399976.XSHE"},
  {"name": "中证内地低碳经济主题指数", "symbol": "399977.XSHE"},
  {"name": "中证医药100指数", "symbol": "399978.XSHE"},
  {"name": "中证大宗商品股票指数", "symbol": "399979.XSHE"},
  {"name": "中证超级大盘指数", "symbol": "399980.XSHE"},
  {"name": "中证500等权重指数", "symbol": "399982.XSHE"},
  {"name": "沪深300地产等权重指数", "symbol": "399983.XSHE"},
  {"name": "中证银行指数", "symbol": "399986.XSHE"},
  {"name": "中证酒指数", "symbol": "399987.XSHE"},
  {"name": "中证医疗指数", "symbol": "399989.XSHE"},
  {"name": "中证煤炭等权指数", "symbol": "399990.XSHE"},
  {"name": "中证一带一路主题指数", "symbol": "399991.XSHE"},
  {"name": "中证万得并购重组指数", "symbol": "399992.XSHE"},
  {"name": "中证万得生物科技指数", "symbol": "399993.XSHE"},
  {"name": "中证信息安全主题指数", "symbol": "399994.XSHE"},
  {"name": "中证基建工程指数", "symbol": "399995.XSHE"},
  {"name": "中证智能家居指数", "symbol": "399996.XSHE"},
  {"name": "中证白酒指数", "symbol": "399997.XSHE"},
  {"name": "中证煤炭指数", "symbol": "399998.XSHE"}
]
"""


def get_list(style='yahoo'):
    df = pd.read_json(StringIO(JSON_DATA))

    if style == 'yahoo':
        df.symbol = df.symbol.apply(lambda x: str(x).replace('XSHG', 'SS').replace('XSHE', 'SZ'))

    return df

@click.command()
@click.argument("outputdir")
def gen_data(outputdir):
    """
    gen all ticker data result to output dir
    """

    if not os.path.isdir(outputdir):
        raise Exception("Please Provide a valid output dir path")



    df = get_list('yahoo')
    for s in df.symbol:

        outputfile = os.path.join(outputdir, '%s_benchmark.csv' % str(s).upper())

        """
        zhikuang-squant is a private command of RainX
        """
        click.echo("generate file or %s " % s)
        cmd = 'zhikuang-squant gen_zipline_benchmark_file -s %s -o %s' % (s, outputfile)
        # click.echo(cmd)
        os.system(cmd)
        click.echo("done! in path : %s" % outputfile)

if __name__ == "__main__":
    gen_data()
